Index: src/heap/spaces.cc |
diff --git a/src/heap/spaces.cc b/src/heap/spaces.cc |
index 2e6ded546f45ecc33b2ff90b31d57d89d59685a3..0feba10c16d05aa708581aee010fcdd927584a93 100644 |
--- a/src/heap/spaces.cc |
+++ b/src/heap/spaces.cc |
@@ -3156,11 +3156,13 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
// strings), fixed arrays, byte arrays, and constant pool arrays in the |
// large object space. |
CHECK(object->IsAbstractCode() || object->IsSeqString() || |
- object->IsExternalString() || object->IsFixedArray() || |
- object->IsFixedDoubleArray() || object->IsByteArray()); |
+ object->IsExternalString() || object->IsThinString() || |
+ object->IsFixedArray() || object->IsFixedDoubleArray() || |
+ object->IsByteArray()); |
// The object itself should look OK. |
object->ObjectVerify(); |
@@ -3156,11 +3156,13 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
- // strings), fixed arrays, byte arrays, and constant pool arrays in the |
- // large object space. |
+ // strings), thin strings (sequential strings that have been |
+ // morphed into thin strings), fixed arrays, byte arrays, and |
+ // constant pool arrays in the large object space. |
CHECK(object->IsAbstractCode() || object->IsSeqString() || |